==============================================================
 :mod:`xoeuf.models.extensions` -- Extensions to Odoo models.
==============================================================

.. automodule:: xoeuf.models.extensions

.. autofunction:: search_read(self, cr, uid, domain=None, fields=None, context=None, *, offset=None, limit=None, order=None, ensure_list=False)

.. autofunction:: search_browse(self, cr, uid, domain=None, context=None, *, offset=None, limit=None, order=None, ensure_list=False)

.. autofunction:: field_value

.. autofunction:: search_value

.. autofunction:: obj_ref

.. autofunction:: get_writer(model, [cr, uid, ids, context=None])

.. autofunction:: get_creator(model, [cr, uid, context=None])

.. autofunction:: cascade_search(self, cr, uid, *queries, context=None)
